# Intermediate Tutorials

These tutorials cover more advanced DFT applications.

## Overview

| Tutorial | Topic | Description | Notebook |
|----------|-------|-------------|----------|
| 06 | Band Structure | Band dispersion along k-paths | [View](https://github.com/jkitchin/vasp/blob/master/docs/tutorials/06_band_structure.ipynb) |
| 07 | Magnetism | Spin-polarized calculations | [View](https://github.com/jkitchin/vasp/blob/master/docs/tutorials/07_magnetism.ipynb) |
| 08 | Surfaces | Slab calculations | [View](https://github.com/jkitchin/vasp/blob/master/docs/tutorials/08_surfaces.ipynb) |
| 09 | Adsorption | Molecules on surfaces | [View](https://github.com/jkitchin/vasp/blob/master/docs/tutorials/09_adsorption.ipynb) |
| 10 | Reactions | Reaction energetics | [View](https://github.com/jkitchin/vasp/blob/master/docs/tutorials/10_reactions.ipynb) |

## Topics Covered

### 06 - Band Structure

Learn how to:
- Define k-point paths through high-symmetry points
- Calculate band structure non-self-consistently
- Identify direct vs. indirect band gaps

### 07 - Magnetism

Learn how to:
- Enable spin polarization (ISPIN=2)
- Set initial magnetic moments
- Apply DFT+U for correlated systems

### 08 - Surfaces

Learn how to:
- Create slab models
- Apply dipole corrections
- Calculate surface energy

### 09 - Adsorption

Learn how to:
- Add adsorbates to surfaces
- Calculate adsorption energies
- Compare adsorption sites

### 10 - Reactions

Learn how to:
- Calculate reaction energies
- Scan potential energy surfaces
- Understand transition state concepts
